

import {Component, ViewChild} from '@angular/core';
import {Platform, App, MenuController, Nav} from 'ionic-angular';
import {StatusBar} from '@ionic-native/status-bar';
import {HeaderColor} from '@ionic-native/header-color';
import {SplashScreen} from '@ionic-native/splash-screen';
import {SplitPane} from '../providers/split-pane';
import {Login} from '../pages/login/login';
import {HomePage} from '../pages/home/home';
import {PosPage} from '../pages/pos/pos';
import {OfficePage} from '../pages/office/office';
import {LedgerPage} from '../pages/ledger/ledger';
import {ReportPage} from '../pages/report/report';
import {ProductPage} from '../pages/product/product';
import {PelangganPage} from '../pages/pelanggan/pelanggan';
import {SettingPage} from '../pages/setting/setting';
import {AuthService} from "../providers/auth-service";
import {HelpPage} from '../pages/help/help';

@Component({
    templateUrl: 'app.html'
})

export class MyApp {

    formSettings = {
        theme: 'ios'
    };

    @ViewChild(Nav) nav: Nav;
    rootPage: any = Login;
    public userDetails: any;
    public name: string;
    public jabatan: string;
    pages: Array<{title: string, component: any, icon: string}>;
    DECIMAL_SEPARATOR = ".";
    GROUP_SEPARATOR = ",";
    budget = 0;
    userData = {
        username: "",
        name: "",
        jabatan: ""
    }

    constructor(private headerColor: HeaderColor,
        platform: Platform,
        public authService: AuthService,
        statusBar: StatusBar,
        splashScreen: SplashScreen,
        public app: App,
        public splitPane: SplitPane,
        public menu: MenuController) {
        platform.ready().then(() => {
            splashScreen.hide();
        });
        this.pages = [
            {title: 'Beranda', component: HomePage, icon: "kara-home"},
            {title: 'Point Of Sale', component: PosPage, icon: "kara-cashier"},
            {title: 'Back Office', component: OfficePage, icon: "kara-office"},
            {title: 'Bukti Penjualan', component: LedgerPage, icon: "kara-penjualan"},
            {title: 'Laporan', component: ReportPage, icon: "kara-laporan"},
            {title: 'Produk', component: ProductPage, icon: "kara-tag"},
            {title: 'Pelanggan', component: PelangganPage, icon: "kara-users"}
        ];
        var validation = localStorage.getItem("userData");
        if (validation !== null) {
            const data = JSON.parse(localStorage.getItem("userData"));
            this.name = data.userData.name;
            this.jabatan = data.userData.jabatan;
        }

        this.headerColor.tint('#2992cb');
    }
    backToWelcome() {
        const root = this.app.getRootNav();
        root.popToRoot();
    }

    pengaturan() {
        this.nav.setRoot(SettingPage);
    }

    bantuan() {
        this.nav.setRoot(HelpPage);
    }

    logout() {
        //Api Token Logout 
        localStorage.clear();
        this.menu.enable(false);
        this.nav.setRoot(Login);
    }
    
    deleteAllCart() {
        this.authService.postData('', "deleteAllCart").then(
            result => {},
            err => {
                
            }
        );
    }
    openPage(page) {
        this.deleteAllCart();
        this.nav.setRoot(page.component);
    }

}
